@@ -35,11 +35,7 @@ function CopyText(props) {
 function TLink(props) {
     const { className, onClick, children } = props;
     return (
-        <button
-            {...{ onClick }}
-            type="button"
-            className={"TLink " + (className || "")}
-        >
+        <button {...{ onClick }} type="button" className={`TLink ${className}`}>
             {children}
         </button>
     );
@@ -51,7 +47,7 @@ function SLink(props) {
         <button
             {...{ onClick }}
             type="button"
-            className={"SLink material-icons " + (className || "")}
+            className={`SLink material-icons ${className}`}
         >
             {children}
         </button>
@@ -162,17 +158,16 @@ function syncPost(url, data) {
     const form = document.createElement("form");
     form.method = "post";
     form.action = url;
-    data.csrfmiddlewaretoken = Cookies.get("csrftoken");
 
-    for (const key in data) {
-        if (data.hasOwnProperty(key)) {
-            const hiddenField = document.createElement("input");
-            hiddenField.type = "hidden";
-            hiddenField.name = key;
-            hiddenField.value = data[key];
+    data.push(["csrfmiddlewaretoken", Cookies.get("csrftoken")]);
 
-            form.appendChild(hiddenField);
-        }
+    for (const [key, value] of data) {
+        const hiddenField = document.createElement("input");
+        hiddenField.type = "hidden";
+        hiddenField.name = key;
+        hiddenField.value = value;
+
+        form.appendChild(hiddenField);
     }
 
     document.body.appendChild(form);
