@@ -139,7 +139,7 @@ def test_get_results_all(get_product_flat):
 
 @pytest.mark.usefixtures("products")
 def test_get_results_unknown_field(get_product_flat):
-    data = get_product_flat(1, "name+!,fake", [])
+    data = get_product_flat(1, "name+1,fake", [])
     assert data == [["a", "phoney"], ["b", "{}"], ["c", "{}"]]
 
 
@@ -160,7 +160,7 @@ def test_get_file_link(get_product_flat):
     models.Product.objects.create(name="a", producer=producer)
     models.Product.objects.create(name="b", producer=producer, image="bob.jpg")
     data = get_product_flat(1, "name,image", [])
-    sortedAssert(data, [["a", ""], ["b", '<a href="/media/bob.jpg">bob.jpg</a>']])
+    sortedAssert(data, [["a", ""], ["b", "/media/bob.jpg"]])
 
 
 def test_get_url_link(get_product_flat):
@@ -168,13 +168,7 @@ def test_get_url_link(get_product_flat):
     models.Product.objects.create(name="a", producer=producer)
     models.Product.objects.create(name="b", producer=producer, url="www.google.com")
     data = get_product_flat(1, "name,url", [])
-    sortedAssert(
-        data,
-        [
-            ["a", None],
-            ["b", '<a href="www.google.com">www.google.com</a>'],
-        ],
-    )
+    sortedAssert(data, [["a", None], ["b", "www.google.com"]])
 
 
 def test_bad_storage(monkeypatch, req):
